(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/forms'), require('@angular/common')) :
    typeof define === 'function' && define.amd ? define('maddob-lib', ['exports', '@angular/core', '@angular/forms', '@angular/common'], factory) :
    (global = global || self, factory(global['maddob-lib'] = {}, global.ng.core, global.ng.forms, global.ng.common));
}(this, (function (exports, core, forms, common) { 'use strict';

    var MarkdownEditorComponent = /** @class */ (function () {
        function MarkdownEditorComponent(required, maxlength) {
            if (required === void 0) { required = false; }
            if (maxlength === void 0) { maxlength = -1; }
            this.required = required;
            this.maxlength = maxlength;
            /** flag for fullscreen mode */
            this.fullscreenEnabled = false;
            /** flag for show/hide preview area */
            this.previewEnabled = true;
            /** flag for disabling the editor (and all its controls) */
            this.disabled = false;
            this.onChange = function (newValue) { };
            this.onTouched = function () { };
        }
        Object.defineProperty(MarkdownEditorComponent.prototype, "value", {
            get: function () {
                return this._value || '';
            },
            set: function (value) {
                this._value = value;
                this.parsedHtml = marked(this._value);
                this.onChange(value);
            },
            enumerable: false,
            configurable: true
        });
        MarkdownEditorComponent.prototype.ngOnInit = function () {
        };
        MarkdownEditorComponent.prototype.ngAfterViewInit = function () {
            var _this = this;
            this.codeMirror = CodeMirror.fromTextArea(this.editor.nativeElement, {
                mode: 'markdown',
                lineNumbers: true,
                autoCloseTags: true,
                lineWrapping: true,
                extraKeys: { 'Ctrl-Space': 'autocomplete' }
            });
            this.codeMirror.doc.on('change', function (instance, change) {
                _this.value = instance.getValue();
            });
            this.resizeCodeMirror();
        };
        /* ControlValueAccessor methods  */
        MarkdownEditorComponent.prototype.writeValue = function (obj) {
            this._value = '';
            if (typeof obj === 'string' && this.codeMirror) {
                this.codeMirror.setValue(obj);
                this.onChange(obj);
            }
        };
        MarkdownEditorComponent.prototype.registerOnChange = function (fn) {
            this.onChange = fn;
        };
        MarkdownEditorComponent.prototype.registerOnTouched = function (fn) {
            this.onTouched = fn;
        };
        MarkdownEditorComponent.prototype.setDisabledState = function (isDisabled) {
            this.disabled = isDisabled;
            if (this.codeMirror) {
                this.codeMirror.setOption('readOnly', isDisabled);
            }
        };
        /* END ControlValueAccessor methods  */
        /**
         * Validate implementation
         *
         * only required and maxlength for now
         */
        MarkdownEditorComponent.prototype.validate = function (control) {
            var result = null;
            if (this.required && this._value.length === 0) {
                result = { required: true };
            }
            if (this.maxlength > 0 && this.value.length > this.maxlength) {
                result = { maxlength: true };
            }
            return result;
        };
        /**
         * Resizes the code mirror instance to the size of the container
         *
         * Used when the code mirror editor element size is changed (window resize, )
         */
        MarkdownEditorComponent.prototype.resizeCodeMirror = function () {
            var _this = this;
            setTimeout(function () {
                var editorContainer = _this.editor.nativeElement.parentNode;
                _this.codeMirror.setSize(editorContainer.offsetWidth, editorContainer.offsetHeight);
            }, 200);
        };
        MarkdownEditorComponent.prototype.toggleFullscreen = function () {
            this.fullscreenEnabled = !this.fullscreenEnabled;
            this.resizeCodeMirror();
        };
        MarkdownEditorComponent.prototype.togglePreview = function () {
            this.previewEnabled = !this.previewEnabled;
            this.resizeCodeMirror();
        };
        /**
         * Inserts special content into the editor
         *
         * can be used for different buttons like bold, italic,
         *
         * Override the method if you want to customize the behaviour of the
         * insertion. For example if you have an own image selector and so on.
         *
         * @param type type of the content that is to be inserted
         * @param value optional value (for special custom content)
         */
        MarkdownEditorComponent.prototype.insertContent = function (type, value) {
            var from = this.codeMirror.getCursor('from');
            // if value is set, use it, if not get the selection instead
            var selection = value ? value : this.codeMirror.getSelection();
            var to = this.codeMirror.getCursor('to');
            var newCursorPosition = { line: to.line, ch: to.ch };
            var additionalOffset = 0;
            var replacement = '';
            switch (type) {
                case 'bold':
                    replacement = "**" + selection + "**";
                    this.codeMirror.replaceRange(replacement, from, to);
                    additionalOffset = 2;
                    break;
                case 'italic':
                    replacement = "*" + selection + "*";
                    this.codeMirror.replaceRange(replacement, from, to);
                    additionalOffset = 1;
                    break;
                case 'quote':
                    replacement = "> " + this.codeMirror.getLine(from.line);
                    this.codeMirror.replaceRange(replacement, { line: from.line, ch: 0 }, { line: from.line, ch: replacement.length });
                    break;
                case 'list':
                    replacement = "- " + this.codeMirror.getLine(from.line);
                    this.codeMirror.replaceRange(replacement, { line: from.line, ch: 0 }, { line: from.line, ch: replacement.length });
                    break;
                case 'link':
                    replacement = "[](" + selection + ")";
                    this.codeMirror.replaceRange(replacement, from, to);
                    additionalOffset = 1;
                    break;
                case 'image':
                    replacement = "![](" + selection + ")";
                    this.codeMirror.replaceRange(replacement, from, to);
                    additionalOffset = 2;
                    break;
                case 'code':
                    replacement = "```\r\n" + selection + "\r\n```";
                    this.codeMirror.replaceRange(replacement, from, to);
                    additionalOffset = 4;
                    break;
                default:
            }
            newCursorPosition.ch += replacement.length - selection.length - additionalOffset;
            this.codeMirror.setCursor(newCursorPosition);
            this.codeMirror.focus();
            this.onChange(this._value);
        };
        return MarkdownEditorComponent;
    }());
    MarkdownEditorComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'maddob-markdown-editor',
                    template: "<div class=\"maddob-markdown-editor-container\" [ngClass]=\"{'fullscreen': fullscreenEnabled}\">\n  \n    <!-- HEADER -->\n    <div class=\"maddob-markdown-editor-header\">\n  \n      <div class=\"maddob-markdown-editor-left\">\n        <button [disabled]=\"disabled\" (click)=\"insertContent('bold')\">bold</button>\n        <button [disabled]=\"disabled\" (click)=\"insertContent('italic')\">italic</button>\n        <button [disabled]=\"disabled\" (click)=\"insertContent('quote')\">quote</button>\n        <button [disabled]=\"disabled\" (click)=\"insertContent('code')\">code</button>\n      </div>\n  \n      <div class=\"maddob-markdown-editor-center\">\n          <button [disabled]=\"disabled\"  (click)=\"insertContent('list')\">list</button>\n          <button [disabled]=\"disabled\"  (click)=\"insertContent('link')\">link</button>\n          <button [disabled]=\"disabled\"  (click)=\"insertContent('image')\">image</button>\n        </div>\n  \n      <div class=\"maddob-markdown-editor-right\">\n        <button (click)=\"togglePreview()\">preview on</button>\n        <button (click)=\"toggleFullscreen()\">fullscreen</button>\n      </div>\n      \n    </div>\n  \n    <!-- CONTENT -->\n    <div class=\"maddob-markdown-editor-content\">\n  \n      <div class=\"maddob-markdown-editor\" (window:resize)=\"resizeCodeMirror()\"\n        [ngClass]=\"{'default-height': !fullscreenEnabled, 'full-height': fullscreenEnabled}\">\n          <textarea #editor></textarea>\n      </div>\n  \n      <div class=\"maddob-markdown-preview\" [innerHTML]=\"parsedHtml\" *ngIf=\"previewEnabled\"\n        [ngClass]=\"{'default-height': !fullscreenEnabled, 'full-height': fullscreenEnabled}\">\n      </div>\n  \n    </div>\n  </div>\n  ",
                    providers: [
                        {
                            provide: forms.NG_VALUE_ACCESSOR,
                            multi: true,
                            useExisting: core.forwardRef(function () { return MarkdownEditorComponent; }),
                        },
                        {
                            provide: forms.NG_VALIDATORS,
                            multi: true,
                            useExisting: core.forwardRef(function () { return MarkdownEditorComponent; })
                        }
                    ],
                    styles: [".maddob-markdown-editor-container{border:1px solid #000;display:flex;flex-direction:column}.maddob-markdown-editor-header{display:flex;flex-direction:row;justify-content:space-between;padding:5px}.maddob-markdown-editor-header-left{display:flex;justify-content:flex-start}.maddob-markdown-editor-header-center{display:flex;flex-grow:0;justify-content:center}.maddob-markdown-editor-header-right{display:flex;justify-content:flex-end}.maddob-markdown-editor-content{border-top:1px solid #000;display:flex;flex-direction:row;flex-grow:1}.maddob-markdown-editor{flex-basis:50%;flex-grow:1;overflow:scroll;text-align:left}.maddob-markdown-editor textarea{height:100%;width:100%}.maddob-markdown-preview{border-left:1px solid #ccc;flex-basis:50%;overflow:scroll;padding:5px;text-align:left}.default-height{height:300px}.full-height{height:100%}.fullscreen{background-color:#fff;height:100%;left:0;overflow:hidden;position:fixed;top:0;width:100%;z-index:1000}"]
                },] }
    ];
    MarkdownEditorComponent.ctorParameters = function () { return [
        { type: Boolean, decorators: [{ type: core.Attribute, args: ['required',] }] },
        { type: Number, decorators: [{ type: core.Attribute, args: ['maxlength',] }] }
    ]; };
    MarkdownEditorComponent.propDecorators = {
        editor: [{ type: core.ViewChild, args: ["editor", { static: true },] }]
    };

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */
    /* global Reflect, Promise */
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b)
                if (Object.prototype.hasOwnProperty.call(b, p))
                    d[p] = b[p]; };
        return extendStatics(d, b);
    };
    function __extends(d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }
    var __assign = function () {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p))
                        t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };
    function __rest(s, e) {
        var t = {};
        for (var p in s)
            if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                    t[p[i]] = s[p[i]];
            }
        return t;
    }
    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
            r = Reflect.decorate(decorators, target, key, desc);
        else
            for (var i = decorators.length - 1; i >= 0; i--)
                if (d = decorators[i])
                    r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }
    function __param(paramIndex, decorator) {
        return function (target, key) { decorator(target, key, paramIndex); };
    }
    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
            return Reflect.metadata(metadataKey, metadataValue);
    }
    function __awaiter(thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try {
                step(generator.next(value));
            }
            catch (e) {
                reject(e);
            } }
            function rejected(value) { try {
                step(generator["throw"](value));
            }
            catch (e) {
                reject(e);
            } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    }
    function __generator(thisArg, body) {
        var _ = { label: 0, sent: function () { if (t[0] & 1)
                throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function () { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f)
                throw new TypeError("Generator is already executing.");
            while (_)
                try {
                    if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done)
                        return t;
                    if (y = 0, t)
                        op = [op[0] & 2, t.value];
                    switch (op[0]) {
                        case 0:
                        case 1:
                            t = op;
                            break;
                        case 4:
                            _.label++;
                            return { value: op[1], done: false };
                        case 5:
                            _.label++;
                            y = op[1];
                            op = [0];
                            continue;
                        case 7:
                            op = _.ops.pop();
                            _.trys.pop();
                            continue;
                        default:
                            if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                                _ = 0;
                                continue;
                            }
                            if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) {
                                _.label = op[1];
                                break;
                            }
                            if (op[0] === 6 && _.label < t[1]) {
                                _.label = t[1];
                                t = op;
                                break;
                            }
                            if (t && _.label < t[2]) {
                                _.label = t[2];
                                _.ops.push(op);
                                break;
                            }
                            if (t[2])
                                _.ops.pop();
                            _.trys.pop();
                            continue;
                    }
                    op = body.call(thisArg, _);
                }
                catch (e) {
                    op = [6, e];
                    y = 0;
                }
                finally {
                    f = t = 0;
                }
            if (op[0] & 5)
                throw op[1];
            return { value: op[0] ? op[1] : void 0, done: true };
        }
    }
    var __createBinding = Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        Object.defineProperty(o, k2, { enumerable: true, get: function () { return m[k]; } });
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    });
    function __exportStar(m, o) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p))
                __createBinding(o, m, p);
    }
    function __values(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m)
            return m.call(o);
        if (o && typeof o.length === "number")
            return {
                next: function () {
                    if (o && i >= o.length)
                        o = void 0;
                    return { value: o && o[i++], done: !o };
                }
            };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    }
    function __read(o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m)
            return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
                ar.push(r.value);
        }
        catch (error) {
            e = { error: error };
        }
        finally {
            try {
                if (r && !r.done && (m = i["return"]))
                    m.call(i);
            }
            finally {
                if (e)
                    throw e.error;
            }
        }
        return ar;
    }
    function __spread() {
        for (var ar = [], i = 0; i < arguments.length; i++)
            ar = ar.concat(__read(arguments[i]));
        return ar;
    }
    function __spreadArrays() {
        for (var s = 0, i = 0, il = arguments.length; i < il; i++)
            s += arguments[i].length;
        for (var r = Array(s), k = 0, i = 0; i < il; i++)
            for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
                r[k] = a[j];
        return r;
    }
    ;
    function __await(v) {
        return this instanceof __await ? (this.v = v, this) : new __await(v);
    }
    function __asyncGenerator(thisArg, _arguments, generator) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var g = generator.apply(thisArg, _arguments || []), i, q = [];
        return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
        function verb(n) { if (g[n])
            i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
        function resume(n, v) { try {
            step(g[n](v));
        }
        catch (e) {
            settle(q[0][3], e);
        } }
        function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
        function fulfill(value) { resume("next", value); }
        function reject(value) { resume("throw", value); }
        function settle(f, v) { if (f(v), q.shift(), q.length)
            resume(q[0][0], q[0][1]); }
    }
    function __asyncDelegator(o) {
        var i, p;
        return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
        function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }
    }
    function __asyncValues(o) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var m = o[Symbol.asyncIterator], i;
        return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
        function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
        function settle(resolve, reject, d, v) { Promise.resolve(v).then(function (v) { resolve({ value: v, done: d }); }, reject); }
    }
    function __makeTemplateObject(cooked, raw) {
        if (Object.defineProperty) {
            Object.defineProperty(cooked, "raw", { value: raw });
        }
        else {
            cooked.raw = raw;
        }
        return cooked;
    }
    ;
    var __setModuleDefault = Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    };
    function __importStar(mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    }
    function __importDefault(mod) {
        return (mod && mod.__esModule) ? mod : { default: mod };
    }
    function __classPrivateFieldGet(receiver, privateMap) {
        if (!privateMap.has(receiver)) {
            throw new TypeError("attempted to get private field on non-instance");
        }
        return privateMap.get(receiver);
    }
    function __classPrivateFieldSet(receiver, privateMap, value) {
        if (!privateMap.has(receiver)) {
            throw new TypeError("attempted to set private field on non-instance");
        }
        privateMap.set(receiver, value);
        return value;
    }

    var UikitMarkdownEditorComponent = /** @class */ (function (_super) {
        __extends(UikitMarkdownEditorComponent, _super);
        function UikitMarkdownEditorComponent() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        UikitMarkdownEditorComponent.prototype.ngOnInit = function () {
        };
        UikitMarkdownEditorComponent.prototype.resizeCodeMirror = function () {
            var _this = this;
            setTimeout(function () {
                var editorContainer = _this.editor.nativeElement.parentNode;
                _this.codeMirror.setSize(editorContainer.offsetWidth - 50, editorContainer.offsetHeight);
            }, 200);
        };
        return UikitMarkdownEditorComponent;
    }(MarkdownEditorComponent));
    UikitMarkdownEditorComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'maddob-uikit-markdown-editor',
                    template: "<div [ngClass]=\"{'fullscreen': fullscreenEnabled}\" class=\"full-border\">\n  <div class=\"CodeMirror-Editor-Tab uk-background-muted uk-flex\">\n    <div class=\"uk-flex uk-flex-left\">\n      <a uk-icon=\"icon: bold\" (click)=\"insertContent('bold')\" uk-tooltip=\"title: Bold; delay: 800\"></a>\n      <a uk-icon=\"icon: italic\" (click)=\"insertContent('italic')\" uk-tooltip=\"title: Italic; delay: 800\"></a>\n      <a uk-icon=\"icon: quote-right\" (click)=\"insertContent('quote')\" uk-tooltip=\"title: Blockquote; delay: 800\"></a>\n    </div>\n\n    <div class=\"uk-flex uk-flex-left uk-margin-left separator\"></div>\n\n    <div class=\"uk-flex uk-flex-left uk-margin-left\">\n      <a uk-icon=\"icon: list\" (click)=\"insertContent('list')\" uk-tooltip=\"title: List; delay: 800\"></a>\n      <a uk-icon=\"icon: code\" (click)=\"insertContent('code')\" uk-tooltip=\"title: Code; delay: 800\"></a>\n    </div>\n\n    <div class=\"uk-flex uk-flex-left uk-margin-left separator\"></div>\n\n    <div class=\"uk-flex uk-flex-left uk-margin-left\">\n      <a uk-icon=\"icon: link\" (click)=\"insertContent('link')\" uk-tooltip=\"title: Link; delay: 800\"></a>\n      <a uk-icon=\"icon: image\" (click)=\"insertContent('image')\" uk-tooltip=\"title: image; delay: 800\"></a>\n    </div>\n\n    <div class=\"uk-flex uk-flex-left uk-margin-left separator\"></div>\n\n    <div class=\"uk-flex uk-flex-left uk-margin-left\">\n      <a *ngIf=\"previewEnabled\" uk-icon=\"icon: chevron-right\" (click)=\"previewEnabled = false; resizeCodeMirror()\"></a>\n      <a *ngIf=\"!previewEnabled\" uk-icon=\"icon: chevron-left\" (click)=\"previewEnabled = true; resizeCodeMirror()\"></a>\n    </div>\n\n    <div class=\"uk-flex uk-flex-right\" style=\"flex-grow: 1;\">\n      <a *ngIf=\"!fullscreenEnabled\" uk-icon=\"icon: expand\" (click)=\"toggleFullscreen()\"></a>\n      <a *ngIf=\"fullscreenEnabled\" uk-icon=\"icon: shrink\" (click)=\"toggleFullscreen()\"></a>\n    </div>\n  </div>\n\n\n  <div class=\"editor-content\" class=\"uk-grid\" uk-grid\n    [ngClass]=\"{'max-height': !fullscreenEnabled, 'full-height': fullscreenEnabled}\">\n    <div class=\"code-mirror-container\"\n      [ngClass]=\"{'uk-width-1-2': previewEnabled, 'uk-width-expand': !previewEnabled, 'max-height': !fullscreenEnabled}\"\n      #codeMirrorContainer (window:resize)=\"resizeCodeMirror()\">\n      <textarea #editor name=\"content\"></textarea>\n    </div>\n    <div *ngIf=\"previewEnabled\" class=\"preview\" [ngClass]=\"{'uk-width-1-2': previewEnabled, 'hidden': !previewEnabled }\"\n      [innerHTML]=\"parsedHtml\"></div>\n  </div>\n</div>",
                    providers: [
                        {
                            provide: forms.NG_VALUE_ACCESSOR,
                            multi: true,
                            useExisting: core.forwardRef(function () { return UikitMarkdownEditorComponent; }),
                        },
                        {
                            provide: forms.NG_VALIDATORS,
                            multi: true,
                            useExisting: core.forwardRef(function () { return UikitMarkdownEditorComponent; })
                        }
                    ],
                    styles: [".full-border,.html-editor-container{border:1px solid #e5e5e5}.CodeMirror-Editor-Tab{border-bottom:1px solid #e5e5e5;padding:10px}.editor-content{border:1px solid #e5e5e5}.fullscreen{height:100%;left:0;overflow:hidden;position:fixed;top:0;width:100%;z-index:1000}.preview{border-left:1px solid #e5e5e5;height:300px;overflow:scroll;overflow-wrap:break-word;padding:5px}.hidden{display:none}.max-height{height:300px;overflow:scroll}.full-height,.full-height>.uk-width-1-2>.CodeMirror,.full-height textarea{height:100%}.full-height div{background-color:#fff;display:block;height:100%}#preview-content{background:#fff;padding:5px}.uk-icon{padding:0 5px}.separator{background-color:#e5e5e5;width:1px}"]
                },] }
    ];

    var SECONDS_MINUTE = 60;
    var SECONDS_HOUR = 60 * SECONDS_MINUTE;
    var SECONDS_DAY = 24 * SECONDS_HOUR;
    /**
     * Transforms values in seconds in readable format
     *
     * Days is the max displayed period. If more than 2
     * period types are available, just two are displayed
     *
     * For example if hours, minutes and seconds are available,
     * seconds are omitted
     *
     * Check test cases for more details
     *
     */
    var ReadableTimePipe = /** @class */ (function () {
        function ReadableTimePipe() {
        }
        ReadableTimePipe.prototype.transform = function (value) {
            if (value < 0) {
                return '';
            }
            var seconds = value;
            var minutes = seconds / SECONDS_MINUTE;
            var hours = seconds / SECONDS_HOUR;
            var days = value / SECONDS_DAY;
            if (days > 1) {
                days = Math.floor(days);
                seconds = seconds - days * SECONDS_DAY;
                hours = seconds / SECONDS_HOUR;
            }
            if (hours > 1) {
                hours = Math.floor(hours);
                seconds = seconds - hours * SECONDS_HOUR;
                minutes = seconds / SECONDS_MINUTE;
            }
            if (minutes > 1) {
                minutes = Math.floor(minutes);
                seconds = seconds - minutes * SECONDS_MINUTE;
            }
            seconds = Math.floor(seconds);
            var parts = [];
            if (days > 1) {
                parts.push(days + "d");
            }
            if (hours > 1) {
                parts.push(hours + "h");
            }
            if (minutes > 1 && parts.length < 2) {
                parts.push(minutes + "m");
            }
            if (parts.length < 2) {
                parts.push(seconds + "s");
            }
            return parts.join(' ');
        };
        return ReadableTimePipe;
    }());
    ReadableTimePipe.decorators = [
        { type: core.Pipe, args: [{
                    name: 'readableTime'
                },] }
    ];

    var MaddobLibModule = /** @class */ (function () {
        function MaddobLibModule() {
        }
        return MaddobLibModule;
    }());
    MaddobLibModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [MarkdownEditorComponent, UikitMarkdownEditorComponent, ReadableTimePipe],
                    imports: [
                        common.CommonModule,
                        forms.FormsModule
                    ],
                    exports: [MarkdownEditorComponent, UikitMarkdownEditorComponent, ReadableTimePipe]
                },] }
    ];

    /*
     * Public API Surface of maddob-lib
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.MaddobLibModule = MaddobLibModule;
    exports.MarkdownEditorComponent = MarkdownEditorComponent;
    exports.ReadableTimePipe = ReadableTimePipe;
    exports.UikitMarkdownEditorComponent = UikitMarkdownEditorComponent;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=maddob-lib.umd.js.map
